==> linux-2.6.5.tar.bz2: linux-2.6.5/drivers/net/ixgb/ixgb_ids.h <==
/*******************************************************************************

  
  Copyright(c) 1999 - 2003 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  Linux NICS <linux.nics@intel.com>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
*******************************************************************************/

#ifndef _IXGB_IDS_H_
#define _IXGB_IDS_H_

/**********************************************************************
** The Device and Vendor IDs for 10 Gigabit MACs
**********************************************************************/

#define INTEL_VENDOR_ID         0x8086
#define INTEL_SUBVENDOR_ID      0x8086

#define IXGB_DEVICE_ID_82597EX 	0x1048
#define IXGB_SUBDEVICE_ID_A11F  0xA11F	/* Adapter-OEM-1310nm-Fiber */
#define IXGB_SUBDEVICE_ID_A01F	0xA01F	/* Adapter-Retail-1310nm-Fiber */

#endif				/* #ifndef _IXGB_IDS_H_ */

/* End of File */

==> linux-2.6.8.tar.bz2: linux-2.6.8/drivers/net/ixgb/ixgb_ids.h <==
/*******************************************************************************

  
  Copyright(c) 1999 - 2004 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  Linux NICS <linux.nics@intel.com>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#ifndef _IXGB_IDS_H_
#define _IXGB_IDS_H_

/**********************************************************************
** The Device and Vendor IDs for 10 Gigabit MACs
**********************************************************************/

#define INTEL_VENDOR_ID         0x8086
#define INTEL_SUBVENDOR_ID      0x8086

#define IXGB_DEVICE_ID_82597EX      0x1048
#define IXGB_DEVICE_ID_82597EX_SR   0x1A48

#define IXGB_SUBDEVICE_ID_A11F  0xA11F
#define IXGB_SUBDEVICE_ID_A01F  0xA01F

#define IXGB_SUBDEVICE_ID_A15F  0xA15F
#define IXGB_SUBDEVICE_ID_A05F  0xA05F

#define IXGB_SUBDEVICE_ID_A12F  0xA12F
#define IXGB_SUBDEVICE_ID_A02F  0xA02F

#endif				/* #ifndef _IXGB_IDS_H_ */

/* End of File */
